@@ -497,6 +497,11 @@ impl InstallBuilder {
         self.args.only = Some(pkg);
         self
     }
+
+    pub fn with_environment(mut self, env: Vec<String>) -> Self {
+        self.args.environment = Some(env);
+        self
+    }
 }
 
 impl IntoFuture for InstallBuilder {
@@ -616,6 +621,17 @@ pub struct LockBuilder {
     pub args: lock::Args,
 }
 
+impl LockBuilder {
+    pub fn with_dry_run(mut self, dry_run: bool) -> Self {
+        self.args.dry_run = dry_run;
+        self
+    }
+    pub fn with_check(mut self, check: bool) -> Self {
+        self.args.check = check;
+        self
+    }
+}
+
 impl IntoFuture for LockBuilder {
     type Output = miette::Result<()>;
     type IntoFuture = Pin<Box<dyn Future<Output = Self::Output> + 'static>>;
