@@ -37,8 +37,8 @@ use pixi_core::{
 use pixi_manifest::{EnvironmentName, FeatureName};
 use pixi_progress::global_multi_progress;
 use pixi_task::{
-    ExecutableTask, RunOutput, SearchEnvironments, TaskExecutionError, TaskGraph, TaskGraphError,
-    TaskName, get_task_env,
+    ExecutableTask, PreferExecutable, RunOutput, SearchEnvironments, TaskExecutionError, TaskGraph,
+    TaskGraphError, TaskName, get_task_env,
 };
 use rattler_conda_types::{MatchSpec, ParseStrictness::Lenient, Platform};
 use rattler_lock::{LockFile, LockedPackageRef, UrlOrPath};
@@ -591,14 +591,25 @@ impl PixiControl {
                 .map(|e| e.best_platform())
                 .or(Some(Platform::current())),
         );
-        let task_graph = TaskGraph::from_cmd_args(&project, &search_env, args.task, false)
-            .map_err(RunError::TaskGraphError)?;
+        let task_graph = TaskGraph::from_cmd_args(
+            &project,
+            &search_env,
+            args.task,
+            false,
+            if args.executable {
+                PreferExecutable::Always
+            } else {
+                PreferExecutable::TaskFirst
+            },
+            args.templated,
+        )
+        .map_err(RunError::TaskGraphError)?;
 
         // Iterate over all tasks in the graph and execute them.
         let mut task_env = None;
         let mut result = RunOutput::default();
         for task_id in task_graph.topological_order() {
-            let task = ExecutableTask::from_task_graph(&task_graph, task_id);
+            let task = ExecutableTask::from_task_graph(&task_graph, task_id, None);
 
             // Construct the task environment if not already created.
             let task_env = match task_env.as_ref() {
@@ -718,6 +729,7 @@ impl PixiControl {
                 no_install_config: NoInstallConfig { no_install: false },
                 check: false,
                 json: false,
+                dry_run: false,
             },
         }
     }
