@@ -6,6 +6,7 @@ use std::{
     sync::LazyLock,
 };
 
+use dunce::canonicalize;
 use fs_err::tokio as tokio_fs;
 use pixi_cli::run::{self, Args};
 use pixi_cli::{
@@ -1280,8 +1281,8 @@ async fn test_multiple_prefix_update() {
         .finish();
 
     let python_repo_data_record = RepoDataRecord {
+        identifier: python_package.identifier(),
         package_record: python_package.package_record,
-        file_name: "python".to_owned(),
         url: Url::parse(url).unwrap(),
         channel: Some("https://repo.prefix.dev/conda-forge/".to_owned()),
     };
@@ -1294,8 +1295,8 @@ async fn test_multiple_prefix_update() {
         .finish();
 
     let wheel_repo_data_record = RepoDataRecord {
+        identifier: wheel_package.identifier(),
         package_record: wheel_package.package_record,
-        file_name: "wheel".to_owned(),
         url: Url::parse(
             "https://repo.prefix.dev/conda-forge/noarch/wheel-0.45.1-pyhd8ed1ab_1.conda",
         )
@@ -1561,3 +1562,149 @@ async fn test_exclude_newer_pypi() {
         "boltons ==20.2.1".parse().unwrap()
     ));
 }
+
+/// Test that UV_SKIP_WHEEL_FILENAME_CHECK environment variable and pypi-option are respected
+/// when installing wheels with version mismatch between filename and metadata
+#[tokio::test]
+#[cfg_attr(
+    any(not(feature = "online_tests"), not(feature = "slow_integration_tests")),
+    ignore
+)]
+async fn test_uv_skip_wheel_filename_check() {
+    setup_tracing();
+
+    // Create a malformed wheel with version mismatch
+    // Filename says 1.0.0, but METADATA says 2.0.0
+    let wheels_dir = tempdir().unwrap();
+    crate::common::pypi_index::write_malformed_wheel(
+        wheels_dir.path(),
+        "1.0.0", // filename version
+        "2.0.0", // metadata version
+        "test-malformed",
+    )
+    .unwrap();
+
+    let current_platform = Platform::current();
+    let wheel_path = canonicalize(
+        wheels_dir
+            .path()
+            .join("test_malformed-1.0.0-py3-none-any.whl"),
+    )
+    .expect("failed to canonicalize wheel path")
+    .display()
+    .to_string()
+    .replace('\\', "/"); // Convert Windows backslashes to forward slashes for TOML
+
+    // Test 1: Environment variable UV_SKIP_WHEEL_FILENAME_CHECK=1
+    let manifest_env_var = format!(
+        r#"
+    [project]
+    name = "test-malformed-wheel-env"
+    channels = ["https://prefix.dev/conda-forge"]
+    platforms = ["{current_platform}"]
+
+    [dependencies]
+    python = "3.12.*"
+
+    [pypi-dependencies]
+    test-malformed = {{ path = "{wheel_path}" }}
+    "#
+    );
+
+    let pixi =
+        PixiControl::from_manifest(&manifest_env_var).expect("cannot instantiate pixi project");
+
+    // Installation should succeed with UV_SKIP_WHEEL_FILENAME_CHECK=1
+    temp_env::async_with_vars([("UV_SKIP_WHEEL_FILENAME_CHECK", Some("1"))], async {
+        pixi.install()
+            .await
+            .expect("Installation should succeed with UV_SKIP_WHEEL_FILENAME_CHECK=1");
+    })
+    .await;
+
+    // Verify the package is installed
+    let prefix_path = pixi.default_env_path().unwrap();
+    let cache = uv_cache::Cache::temp().unwrap();
+    let env = create_uv_environment(&prefix_path, &cache);
+    assert!(
+        is_pypi_package_installed(&env, "test-malformed"),
+        "Package should be installed with UV_SKIP_WHEEL_FILENAME_CHECK=1"
+    );
+
+    // Test 2: pypi-option skip-wheel-filename-check = true
+    let manifest_pypi_option = format!(
+        r#"
+    [project]
+    name = "test-malformed-wheel-option"
+    channels = ["https://prefix.dev/conda-forge"]
+    platforms = ["{current_platform}"]
+
+    [dependencies]
+    python = "3.12.*"
+
+    [pypi-options]
+    skip-wheel-filename-check = true
+
+    [pypi-dependencies]
+    test-malformed = {{ path = "{wheel_path}" }}
+    "#
+    );
+
+    let pixi_option =
+        PixiControl::from_manifest(&manifest_pypi_option).expect("cannot instantiate pixi project");
+
+    // Installation should succeed with pypi-option
+    pixi_option
+        .install()
+        .await
+        .expect("Installation should succeed with skip-wheel-filename-check = true");
+
+    // Verify the package is installed
+    let prefix_path = pixi_option.default_env_path().unwrap();
+    let cache = uv_cache::Cache::temp().unwrap();
+    let env = create_uv_environment(&prefix_path, &cache);
+    assert!(
+        is_pypi_package_installed(&env, "test-malformed"),
+        "Package should be installed with skip-wheel-filename-check = true"
+    );
+
+    // Test 3: Environment variable takes precedence over pypi-option
+    let manifest_precedence = format!(
+        r#"
+    [project]
+    name = "test-malformed-wheel-precedence"
+    channels = ["https://prefix.dev/conda-forge"]
+    platforms = ["{current_platform}"]
+
+    [dependencies]
+    python = "3.12.*"
+
+    [pypi-options]
+    skip-wheel-filename-check = false
+
+    [pypi-dependencies]
+    test-malformed = {{ path = "{wheel_path}" }}
+    "#
+    );
+
+    let pixi_precedence =
+        PixiControl::from_manifest(&manifest_precedence).expect("cannot instantiate pixi project");
+
+    // Installation should succeed because env var overrides pypi-option
+    temp_env::async_with_vars([("UV_SKIP_WHEEL_FILENAME_CHECK", Some("1"))], async {
+        pixi_precedence
+            .install()
+            .await
+            .expect("Installation should succeed when env var overrides pypi-option");
+    })
+    .await;
+
+    // Verify the package is installed
+    let prefix_path = pixi_precedence.default_env_path().unwrap();
+    let cache = uv_cache::Cache::temp().unwrap();
+    let env = create_uv_environment(&prefix_path, &cache);
+    assert!(
+        is_pypi_package_installed(&env, "test-malformed"),
+        "Package should be installed when env var takes precedence"
+    );
+}
