@@ -2,13 +2,14 @@ use super::common::{
     CacheError, CacheKey, CachedMetadata, MetadataCache, VersionedMetadata,
     WriteResult as CommonWriteResult,
 };
-use crate::input_hash::ProjectModelHash;
-use crate::{BuildEnvironment, PackageIdentifier, build::source_checkout_cache_key};
+use crate::build::CanonicalSourceCodeLocation;
+use crate::input_hash::{ConfigurationHash, ProjectModelHash};
+use crate::{BuildEnvironment, PackageIdentifier};
 use base64::{Engine, engine::general_purpose::URL_SAFE_NO_PAD};
 use pixi_build_discovery::EnabledProtocols;
 use pixi_build_types::procedures::conda_outputs::CondaOutput;
 use pixi_path::AbsPathBuf;
-use pixi_record::{PinnedSourceSpec, VariantValue};
+use pixi_record::VariantValue;
 use rattler_conda_types::ChannelUrl;
 use serde::{Deserialize, Serialize};
 use std::collections::{BTreeSet, BinaryHeap};
@@ -57,7 +58,7 @@ pub struct BuildBackendMetadataCacheShard {
     pub enabled_protocols: EnabledProtocols,
 
     /// The pinned source location
-    pub pinned_source: PinnedSourceSpec,
+    pub source: CanonicalSourceCodeLocation,
 }
 
 impl BuildBackendMetadataCache {
@@ -79,10 +80,6 @@ impl MetadataCache for BuildBackendMetadataCache {
         self.root.as_std_path()
     }
 
-    fn cache_file_name(&self) -> &'static str {
-        "metadata.json"
-    }
-
     const CACHE_SUFFIX: &'static str = "v0";
 }
 
@@ -102,7 +99,7 @@ impl CacheKey for BuildBackendMetadataCacheShard {
         host_virtual_packages.hash(&mut hasher);
 
         self.enabled_protocols.hash(&mut hasher);
-        let source_dir = source_checkout_cache_key(&self.pinned_source);
+        let source_dir = self.source.cache_unique_key();
         format!(
             "{source_dir}/{}-{}",
             self.build_environment.host_platform,
@@ -135,10 +132,19 @@ pub struct CachedCondaMetadata {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub project_model_hash: Option<ProjectModelHash>,
 
+    /// The hash of the build configuration (from `[package.build.config]`).
+    /// This ensures that changes to the build configuration invalidate the
+    /// cache even if the project model hasn't changed.
+    #[serde(default)]
+    pub configuration_hash: ConfigurationHash,
+
     /// The pinned location of the source code. Although the specification of
     /// where to find the source is part of the `project_model_hash`, the
     /// resolved location is not.
-    pub build_source: PinnedSourceSpec,
+    ///
+    /// This is also part of the cache shard but for debug purposes we store
+    /// it in this file as well.
+    pub source: CanonicalSourceCodeLocation,
 
     /// The build variants that were used to generate this metadata.
     #[serde(default, skip_serializing_if = "BTreeMap::is_empty")]
