@@ -20,7 +20,7 @@ impl CommandDispatcherProcessor {
     ) -> SourceBuildCacheStatusId {
         let id = SourceBuildCacheStatusId(self.source_build_cache_status_ids.len());
         self.source_build_cache_status_ids
-            .insert(task.spec.clone(), id);
+            .insert(task.spec.key(), id);
         if let Some(parent) = task.parent {
             self.parent_contexts.insert(id.into(), parent);
         }
@@ -32,7 +32,7 @@ impl CommandDispatcherProcessor {
     pub(crate) fn on_source_build_cache_status(&mut self, task: SourceBuildCacheStatusTask) {
         // Lookup the id of the request to avoid duplication.
         let source_build_cache_status_id = {
-            match self.source_build_cache_status_ids.get(&task.spec) {
+            match self.source_build_cache_status_ids.get(&task.spec.key()) {
                 Some(id) => {
                     // We already have a pending task. Let's make sure that we are not trying to
                     // resolve the same thing in a cycle.
