@@ -461,6 +461,8 @@ pub enum LockFileUsage {
     Locked,
     /// Don't update the lock-file and don't check if it is out of date
     Frozen,
+    /// Don't update the lock-file, but don't check if it is out of date
+    DryRun,
 }
 
 impl LockFileUsage {
@@ -472,7 +474,7 @@ impl LockFileUsage {
     /// Returns true if the lock-file should be checked if it is out of date.
     pub(crate) fn should_check_if_out_of_date(self) -> bool {
         match self {
-            LockFileUsage::Update | LockFileUsage::Locked => true,
+            LockFileUsage::Update | LockFileUsage::Locked | LockFileUsage::DryRun => true,
             LockFileUsage::Frozen => false,
         }
     }
