@@ -43,6 +43,16 @@ fn join_args_with_single_quotes<'a>(args: impl IntoIterator<Item = &'a str>) ->
         .join(" ")
 }
 
+/// Controls whether to prefer resolving commands as executables over Pixi tasks
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Default)]
+pub enum PreferExecutable {
+    /// Try to resolve as a Pixi task first, fall back to executable if no task found
+    #[default]
+    TaskFirst,
+    /// Always treat as an executable, skip task resolution
+    Always,
+}
+
 /// A task ID is a unique identifier for a [`TaskNode`] in a [`TaskGraph`].
 ///
 /// To get a task from a [`TaskGraph`], you can use the [`TaskId`] as an index.
@@ -189,11 +199,19 @@ impl<'p> TaskGraph<'p> {
     }
 
     /// Constructs a new [`TaskGraph`] from a list of command line arguments.
+    ///
+    /// When `prefer_executable` is [`PreferExecutable::Always`], the first
+    /// argument will not be resolved as a Pixi task even if a task with that
+    /// name exists. Instead, the arguments are treated as a custom command to
+    /// execute within the environment, allowing running executables that
+    /// collide with task names.
     pub fn from_cmd_args<D: TaskDisambiguation<'p>>(
         project: &'p Workspace,
         search_envs: &SearchEnvironments<'p, D>,
         args: Vec<String>,
         skip_deps: bool,
+        prefer_executable: PreferExecutable,
+        templated: bool,
     ) -> Result<Self, TaskGraphError> {
         // Split 'args' into arguments if it's a single string, supporting commands
         // like: `"test 1 == 0 || echo failed"` or `"echo foo && echo bar"` or
@@ -208,7 +226,9 @@ impl<'p> TaskGraph<'p> {
             (args, true)
         };
 
-        if let Some(name) = args.first() {
+        if prefer_executable == PreferExecutable::TaskFirst
+            && let Some(name) = args.first()
+        {
             match search_envs.find_task(TaskName::from(name.clone()), FindTaskSource::CmdArgs, None)
             {
                 Err(FindTaskError::MissingTask(_)) => {}
@@ -312,6 +332,7 @@ impl<'p> TaskGraph<'p> {
                     Custom {
                         cmd,
                         cwd: env::current_dir().ok(),
+                        templated,
                     }
                     .into(),
                 ),
@@ -358,8 +379,9 @@ impl<'p> TaskGraph<'p> {
                 let context = pixi_manifest::task::TaskRenderContext {
                     platform: node.run_environment.best_platform(),
                     environment_name: node.run_environment.name(),
-                    manifest_path: None, // manifest_path not available at TaskNode level
+                    manifest_path: None,
                     args: node.args.as_ref(),
+                    init_cwd: None,
                 };
                 let dependency = TypedDependency::from_dependency(&dependency, &context)?;
                 // Check if we visited this node before already.
@@ -613,7 +635,7 @@ mod test {
 
     use crate::{
         task_environment::SearchEnvironments,
-        task_graph::{TaskGraph, join_args_with_single_quotes},
+        task_graph::{PreferExecutable, TaskGraph, join_args_with_single_quotes},
     };
 
     fn commands_in_order(
@@ -622,6 +644,8 @@ mod test {
         platform: Option<Platform>,
         environment_name: Option<EnvironmentName>,
         skip_deps: bool,
+        prefer_executable: PreferExecutable,
+        templated: bool,
     ) -> Vec<String> {
         let project = Workspace::from_str(Path::new("pixi.toml"), project_str).unwrap();
 
@@ -633,6 +657,8 @@ mod test {
             &search_envs,
             run_args.iter().map(|arg| arg.to_string()).collect(),
             skip_deps,
+            prefer_executable,
+            templated,
         )
         .unwrap();
 
@@ -646,6 +672,7 @@ mod test {
                     environment_name: task.run_environment.name(),
                     manifest_path: Some(&project.workspace.provenance.path),
                     args: task.args.as_ref(),
+                    init_cwd: None,
                 };
                 task.full_command(&context).ok().flatten()
             })
@@ -670,7 +697,9 @@ mod test {
                 &["top", "--test"],
                 None,
                 None,
-                false
+                false,
+                PreferExecutable::TaskFirst,
+                false,
             ),
             vec!["echo root", "echo task1", "echo task2", "echo top '--test'"]
         );
@@ -694,7 +723,9 @@ mod test {
                 &["top"],
                 None,
                 None,
-                false
+                false,
+                PreferExecutable::TaskFirst,
+                false,
             ),
             vec!["echo root", "echo task1", "echo task2", "echo top"]
         );
@@ -720,7 +751,9 @@ mod test {
                 &["top"],
                 Some(Platform::Linux64),
                 None,
-                false
+                false,
+                PreferExecutable::TaskFirst,
+                false,
             ),
             vec!["echo linux", "echo task1", "echo task2", "echo top",]
         );
@@ -739,7 +772,9 @@ mod test {
                 &["echo bla"],
                 None,
                 None,
-                false
+                false,
+                PreferExecutable::TaskFirst,
+                false,
             ),
             vec![r#"echo bla"#]
         );
@@ -764,7 +799,9 @@ mod test {
                 &["build"],
                 None,
                 None,
-                false
+                false,
+                PreferExecutable::TaskFirst,
+                false,
             ),
             vec![r#"echo build"#]
         );
@@ -792,7 +829,9 @@ mod test {
                 &["start"],
                 None,
                 None,
-                false
+                false,
+                PreferExecutable::TaskFirst,
+                false,
             ),
             vec![r#"hello world"#]
         );
@@ -824,7 +863,9 @@ mod test {
                 &["start"],
                 None,
                 Some(EnvironmentName::Named("cuda".to_string())),
-                false
+                false,
+                PreferExecutable::TaskFirst,
+                false,
             ),
             vec![r#"python train.py --cuda"#, r#"python test.py --cuda"#]
         );
@@ -854,7 +895,9 @@ mod test {
                 &["foobar"],
                 None,
                 None,
-                false
+                false,
+                PreferExecutable::TaskFirst,
+                false,
             ),
             vec![r#"echo foo"#, r#"echo bar"#]
         );
@@ -886,6 +929,8 @@ mod test {
             None,
             None,
             false,
+            PreferExecutable::TaskFirst,
+            false,
         );
     }
 
@@ -902,11 +947,27 @@ mod test {
         bar = { cmd = "echo bar", depends-on = ["foo"] }
     "#;
         assert_eq!(
-            commands_in_order(project, &["bar"], None, None, true),
+            commands_in_order(
+                project,
+                &["bar"],
+                None,
+                None,
+                true,
+                PreferExecutable::TaskFirst,
+                false,
+            ),
             vec![r#"echo bar"#]
         );
         assert_eq!(
-            commands_in_order(project, &["bar"], None, None, false),
+            commands_in_order(
+                project,
+                &["bar"],
+                None,
+                None,
+                false,
+                PreferExecutable::TaskFirst,
+                false,
+            ),
             vec!["echo foo", "echo bar"]
         );
     }
@@ -931,4 +992,137 @@ mod test {
         let quote_result = join_args_with_single_quotes(quote_args.iter().copied());
         assert_eq!(quote_result, r#"'echo' 'it'"'"'s'"#);
     }
+
+    /// Regression test for https://github.com/prefix-dev/pixi/issues/5478
+    ///
+    /// Verifies that `pixi run echo '{{ hello }}'` does not fail when
+    /// templating is disabled (the default for CLI commands).
+    #[test]
+    fn test_custom_command_with_braces_no_template() {
+        let project = r#"
+        [project]
+        name = "pixi"
+        channels = []
+        platforms = ["linux-64", "osx-64", "win-64", "osx-arm64", "linux-riscv64"]
+        "#;
+
+        let project =
+            Workspace::from_str(Path::new("pixi.toml"), project).expect("valid workspace");
+
+        let search_envs = SearchEnvironments::from_opt_env(&project, None, None);
+
+        // Without --templated, {{ hello }} should pass through as-is.
+        // Multiple args simulate how the shell + clap deliver them:
+        //   pixi run echo '{{ hello }}'
+        // becomes args = ["echo", "{{ hello }}"]
+        let graph = TaskGraph::from_cmd_args(
+            &project,
+            &search_envs,
+            vec!["echo".to_string(), "{{ hello }}".to_string()],
+            false,
+            PreferExecutable::TaskFirst,
+            false,
+        )
+        .expect("should not fail with braces when templating is disabled");
+
+        let order = graph.topological_order();
+        assert_eq!(order.len(), 1);
+        let task = &graph[order[0]];
+        let context = pixi_manifest::task::TaskRenderContext {
+            platform: task.run_environment.best_platform(),
+            environment_name: task.run_environment.name(),
+            manifest_path: Some(&project.workspace.provenance.path),
+            args: task.args.as_ref(),
+            init_cwd: None,
+        };
+        let cmd = task
+            .task
+            .as_single_command(&context)
+            .expect("should not fail")
+            .expect("should have a command");
+        assert!(cmd.contains("{{ hello }}"));
+    }
+
+    /// Verifies that `pixi run --templated echo '{{ pixi.platform }}'`
+    /// renders template variables.
+    #[test]
+    fn test_custom_command_with_templated_flag() {
+        let project = r#"
+        [project]
+        name = "pixi"
+        channels = []
+        platforms = ["linux-64", "osx-64", "win-64", "osx-arm64", "linux-riscv64"]
+        "#;
+
+        let project =
+            Workspace::from_str(Path::new("pixi.toml"), project).expect("valid workspace");
+
+        let search_envs = SearchEnvironments::from_opt_env(&project, None, None);
+
+        // With --templated, {{ pixi.platform }} should be rendered.
+        // Multiple args simulate how the shell + clap deliver them:
+        //   pixi run --templated echo '{{ pixi.platform }}'
+        // becomes args = ["echo", "{{ pixi.platform }}"]
+        let graph = TaskGraph::from_cmd_args(
+            &project,
+            &search_envs,
+            vec!["echo".to_string(), "{{ pixi.platform }}".to_string()],
+            false,
+            PreferExecutable::TaskFirst,
+            true,
+        )
+        .expect("should succeed with valid template variable");
+
+        let order = graph.topological_order();
+        let task = &graph[order[0]];
+        let context = pixi_manifest::task::TaskRenderContext {
+            platform: task.run_environment.best_platform(),
+            environment_name: task.run_environment.name(),
+            manifest_path: Some(&project.workspace.provenance.path),
+            args: task.args.as_ref(),
+            init_cwd: None,
+        };
+        let cmd = task
+            .task
+            .as_single_command(&context)
+            .expect("should render successfully")
+            .expect("should have a command");
+        // The platform should be resolved, not the raw template
+        assert!(!cmd.contains("{{"));
+    }
+
+    #[test]
+    fn test_prefer_executable_always() {
+        let project = r#"
+        [project]
+        name = "pixi"
+        channels = []
+        platforms = ["linux-64"]
+
+        [tasks]
+        foo = "echo from-task"
+        "#;
+
+        let project =
+            Workspace::from_str(Path::new("pixi.toml"), project).expect("valid workspace");
+
+        let search_envs = SearchEnvironments::from_opt_env(&project, None, None);
+
+        let graph = TaskGraph::from_cmd_args(
+            &project,
+            &search_envs,
+            vec!["foo".to_string()],
+            false,
+            PreferExecutable::Always,
+            false,
+        )
+        .expect("graph should be created");
+
+        // When PreferExecutable::Always is used, we should not resolve the command
+        // as a task, even if a task with that name exists.
+        let order = graph.topological_order();
+        assert_eq!(order.len(), 1);
+        let task = &graph[order[0]];
+        assert!(task.name.is_none());
+    }
 }
